"use strict";
(self["webpackChunkjupyterlab_pygments"] = self["webpackChunkjupyterlab_pygments"] || []).push([["lib_index_js"],{

/***/ "./lib/index.js":
/*!**********************!*\
  !*** ./lib/index.js ***!
  \**********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": () => (__WEBPACK_DEFAULT_EXPORT__)
/* harmony export */ });
/**
 * Initialization data for the jupyterlab_pygments extension.
 */
const plugin = {
    id: 'jupyterlab_pygments:plugin',
    autoStart: true,
    activate: (app) => { }
};
/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (plugin);


/***/ })

}]);
//# sourceMappingURL=lib_index_js.3a4ba89e63711a60f25c.js.map